## 0.6.5 (2024-11-24)

### Fix

- log deployed jobs to user

### Refactor

- make _gather_jobs easier to test
- add types to deploy methods
- simplify log_deployed_resources
- return jobs after logging
- handle errors in init
- fix args in make_workflow_name
- move make_workflow_name to utils

[main 9dcf09c] bump: version 0.6.4 → 0.6.5
 2 files changed, 17 insertions(+), 1 deletion(-)

